@@ -68,7 +68,8 @@ def as_json(**response_kwargs):
                     ct = 'application/x-javascript'
                 else:
                     ct = 'application/json'
-                return Response(res, content_type=ct, **response_kwargs)
+                res = Response(res, content_type=ct, **response_kwargs)
+            return res
             wrapper._pysi_urlname = get_urlname(func)
         return wrapper
     return decorator
