@@ -47,7 +47,7 @@ class Request(object):
     def POST(self):
         '''
         Данные POST-запроса.
-        Строковые данные декодируются.
+        Строковые данные НЕ декодируются.
         Файлы:
             rq.POST['datafile'].file.read()  # содержимое файла
             rq.POST['datafile'].filename  # имя файла
@@ -85,9 +85,25 @@ class Request(object):
                 if item.filename:
                     post[item.name] = item  # файл
                 else:
-                    post[item.name] = item.value.decode(self.charset, self.encoding_errors)
+                    post[item.name] = item.value
         return post
 
+    @cached_property
+    def form(self):
+        ret = MultiDict()
+        for k, v in self.POST.iterallitems():
+            if isinstance(v, str):
+                ret[k] = v.decode(self.charset, self.encoding_errors)
+        return ret
+
+    @cached_property
+    def files(self):
+        ret = MultiDict()
+        for k, v in self.POST.iterallitems():
+            if not isinstance(v, str):
+                ret[k] = v
+        return ret
+
     @cached_property
     def COOKIES(self):
         return SimpleCookie(self.environ.get('HTTP_COOKIE', ''))
